Get infer version
==================

.. automodule:: drain_swamp.monkey.wrap_infer_version
   :members:
   :undoc-members:
   :platform: Unix
   :synopsis: entrypoint to run the build plugins manager
